platformdirs: A small Python module for determining appropriate platform-specific dirs, e.g. a "user data dir".
===============================================================================================================

Description
-----------

A small Python module for determining appropriate platform-specific dirs, e.g. a "user data dir".

License
-------

Upstream Contact
----------------

https://pypi.org/project/platformdirs/

